#
# spec file for package nwg-displays
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           nwg-displays
Version:        0.3.20
Release:        1.4
Summary:        A GTK3 wrapper to display text on the desktop for wlroots
License:        MIT
URL:            https://github.com/nwg-piotr/nwg-displays
Source0:        %{url}/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gtk-layer-shell-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
Requires:       libgtk-3-0
Requires:       libgtk-layer-shell0
Requires:       python3-gobject
Requires:       python3-i3ipc
Requires:       typelib(GtkLayerShell)
BuildArch:      noarch

%description

nwg-displays is Output management utility for sway Wayland compositor,
inspired by wdisplays and wlay.

%prep
%autosetup

%build
%py3_build

%install
%py3_install

install -Dpm 0644 %{name}.svg -t %{buildroot}%{_datadir}/pixmaps/
install -Dpm 0644 nwg-displays.svg -t %{buildroot}%{_datadir}/pixmaps/
install -Dpm 0755 %{name}.desktop -t %{buildroot}%{_datadir}/applications/

# fix env-script-interpreter
sed -i '1s|#!/usr/bin/env python|#!/usr/bin/python3|' \
   %{buildroot}%{python_sitelib}/nwg_displays/main.py

# fix non-executable-script
for file in %{buildroot}%{python_sitelib}/nwg_displays/main.py; do
   chmod a+x $file
done

%fdupes %{buildroot}%{python_sitelib}/nwg_displays/__pycache__

%files
%license LICENSE
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/*.desktop
%{_datadir}/pixmaps/*.svg
%{python_sitelib}/nwg_displays
%{python_sitelib}/nwg_displays-*.egg-info

%changelog
* Thu Jul 18 2024 Avindra Goolcharan <avindra@opensuse.org>
- Update to version 0.3.20
  * Added try clause for Gdk.Monitor assignment error #60
  * Added workaround for gtk3-1:3.24.42 Gdk.Monitor bug
  * Hopefully fixed f-string error on python<3.12. #58
  * Added support for upcoming new Hyprland socket files location
    in $XDG_RUNTIME_DIR/hypr.
* Wed Mar 27 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.16
  * dropped dependency on the wlr-randr package, all we need is
    hyprctl monitors;
  * added support for bitdepth 10;
  * added initialization of the "monitor" key, in case we couldn't
    detect and assign a Gdk.Monitor.
* Sat Mar  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Fix some rpmlint issues:
  + Add fdupes BuildRequires: fix files-duplicate
  + fix env-script-interpreter
  + fix non-executable-script
* Sat Mar  2 2024 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.14
  + Added XDG_CONFIG_HOME usage for hyprland config;
  + Added creation of empty files on:
    ~/.config/sway/outputs,
    ~/.config/sway/workspaces,
    ~/.config/hypr/monitors,
    ~/.config/hypr/workspaces,
    (or their equivalents in XDG_CONFIG_HOME if not found)
  + Documentation updated.
  + From now on we rely on the difference between hyprctl monitors
    all and hyprctl monitors output to detect disabled monitors.
  + The DPMS check button works on Hyprland now.
* Sun Dec 10 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.10
  + [Hyprland] Adapter info, if any, stripped from output
    descriptions
  + added check whether output_path exists before reading in backup
* Sat Nov 25 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.9
  + Confirmation popup moved to GtkLayerShell, to prevent it from
    opening off-screen.
* Fri Sep 29 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.8
  + Added popup & countdown timer to restore from improper settings
    ; close
- Simplify spec source url and requires typelib GtkLayerShell
* Sat Jul 29 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.7
* Sun Jun 18 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.3
* Mon May  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- Update to version 0.3.2
* Mon May  1 2023 Muhammad Akbar Yanuar Mantari <mantarimay@pm.me>
- initial package for openSUSE
